@@ -12,17 +12,17 @@ from adnar_scraper.utility.error_file_controller import ErrorFileController
 
 
 class NaverImageScraper:
-    def __init__(self, data_list, full_data_length):
+    def __init__(self, data_list, full_data_length, category_name):
         self.scraper_name = "naver_image_scraper"
         self.kind = "item"
 
         self.starting_time = DataLoader.create_file_name()
         self.save_file_controller = SaveFileController(name=self.scraper_name,
-                                                       date_time=self.starting_time,
+                                                       date_time=category_name + '/' + self.starting_time,
                                                        kind=self.kind)
 
         self.data_list = data_list
-        self.error_file_controller = ErrorFileController(name=self.scraper_name, date_time=self.starting_time)
+        self.error_file_controller = ErrorFileController(name=self.scraper_name, date_time=category_name + '/' + self.starting_time)
 
         self.formal_percent = 0
 
@@ -125,6 +125,12 @@ class NaverImageScraper:
                 print(str(save_list[0]) + '개 입니다.')
 
 if __name__ == "__main__":
+    datas = DataLoader.load_pickle_data(file_path='E:/databases/ver_1/local_database/item_database/separated_category_items/패션의류&여성의류&티셔츠.pkl')
+
+    scraper = NaverImageScraper(data_list=datas, full_data_length=len(datas))
+    scraper.multi_get_image(num_of_process=4)
+
+    '''
     database_controller = DatabaseController(selected_database='item')
 
     splited_file_path_list = database_controller.get_splited_data_path(
@@ -204,7 +210,7 @@ if __name__ == "__main__":
 
         for name in download_file_name :
             print(name)
-
+    '''
     
     '''
     p = DataLoader.load_pickle_data(file_path=settings.ITEM_DATABASE_PATH + 'naver_image_scraper' + '/2020_10_11_15_57/0.pkl')
