@@ -13,7 +13,7 @@ from adnar_scraper.utility.database_controller import DatabaseController
 
 class ShopDetailScraper:
     def __init__(self, data_set):
-        self.scraper_name = "shop_detail_scraper"
+        self.scraper_name = "shop_detail_scraper/ver_1"
         self.kind = "item"
 
         self.selenium_controller = SeleniumController()
@@ -26,10 +26,7 @@ class ShopDetailScraper:
 
         print('Mall count: ' + str(len(self.data_set)))
 
-        self.full_item_length = 0
-
-        for k in self.data_set:
-            self.full_item_length += int(re.sub(pattern=',', repl='', string=k['item_count']))
+        self.full_item_length = 100000
 
     def multi_get_data(self, num_of_process):
         with Manager() as manager:
@@ -48,7 +45,7 @@ class ShopDetailScraper:
                 process_1.join()
                 process_2.join()
 
-            if num_of_process == 3:
+            elif num_of_process == 3:
                 basis = len(self.data_set) // 3
 
                 process_1 = Process(target=self.get_data, args=(0, basis * 1, data_len_list, 1))
@@ -96,7 +93,7 @@ class ShopDetailScraper:
             saving_list = []
             error_list = []
 
-            driver = self.selenium_controller.get_ghost_driver()
+            driver = self.selenium_controller.get_image_blocked_driver(show_browser=False)
 
             reorganized_url = self.reorganize_url(url=data['detail_url'])
 
@@ -117,7 +114,7 @@ class ShopDetailScraper:
                 error_list += extracted_data['error_list']
 
             data_len_list.append(len(saving_list))
-            self.save_file_controller.save_data_each(process_num=process_num, data_set=saving_list)
+            self.save_file_controller.save_data_memory_saving_version(process_num=process_num, data_set=saving_list)
             self.error_file_controller.save_error(process_num=process_num, errors=error_list)
 
             self.selenium_controller.print_percent(full_item_length=self.full_item_length, data_len_list=data_len_list)
@@ -189,6 +186,18 @@ class ShopDetailScraper:
             except Exception as e:
                 print(e)
 
+            # Get Item Price
+            item_price = None
+
+            try :
+                item_price = element.find_element_by_xpath(
+                    xpath='descendant::span[contains(@class, "price_num")]').text
+
+            except Exception as e:
+                print("Error message ! - In stage 1")
+                print(e)
+                error_list.append([e, "Inner"])
+
             # Get Image href
             image_link = None
 
@@ -204,7 +213,7 @@ class ShopDetailScraper:
 
             # Set datas (Categories and data)
             data_set = {'item_name': item_name, 'info_list': filtered_info_list, 'image_link': image_link,
-                        'tag_data': tag_data,
+                        'tag_data': tag_data, 'item_price': item_price,
                         "main_category": main_category, "sub_category": sub_category,
                         "category_name": category_name, "mall_name": mall_name}
 
@@ -216,6 +225,7 @@ class ShopDetailScraper:
     def get_full_page(self, item_count):
         full_page = 0
 
+        item_count = re.sub(pattern='\,', repl='', string=item_count)
         item_count = int(item_count)
 
         if item_count <= 40:
@@ -244,15 +254,7 @@ class ShopDetailScraper:
 
     def deleted_already_in_db(self, mall_db):
         # Get all file in db
-        all_data = self.database_controller.get_all_data_in_path(db_name=settings.ITEM_DATABASE_PATH + self.scraper_name + '/')
-
-        # Get all mall_names
-        mall_names = []
-
-        for data in all_data:
-            mall_names.append(data["mall_name"])
-
-        mall_names = set(mall_names)
+        mall_names = self.database_controller.get_mall_name_in_path(db_name=settings.ITEM_DATABASE_PATH + self.scraper_name + '/')
 
         # return filtered_data_set
         new_filtered_mall_list = []
@@ -273,31 +275,21 @@ class ShopDetailScraper:
 
 if __name__ == "__main__":
     # x~100
-    mall_list = DataLoader.load_pickle_data(file_path=settings.SHOP_DATABASE_PATH + 'shop_FashionCloth_ver_1.pkl')
+    from adnar_scraper.utility.shop_analyzer import ShopAnalyzer
+    from adnar_scraper.settings import LINUX_SHOP_DATABASE_PATH
 
-    new_data_set = []
+    mall_infos = DataLoader.load_pickle_data(file_path=LINUX_SHOP_DATABASE_PATH + 'shop_FashionCloth_ver_1.pkl')
 
-    for k in mall_list:
-        if 9 <= int(re.sub(pattern=',', repl='', string=k['item_count'])) <= 100:
-            new_data_set.append(k)
+    shop_with_items = DatabaseController(selected_database='item').get_shop_count_data(db_name='shop_detail_scraper')
+    shop_with_graphs = DatabaseController(selected_database='local_shop').get_recent_data(
+        db_name='shop_follower_info_scraper')
 
-    data_splited_num = 500
-    basis = len(new_data_set) // data_splited_num
 
-    formal = 0
+    analyzer = ShopAnalyzer()
 
-    for i in range(basis) :
-        splited_data_set = new_data_set[formal:data_splited_num * (i + 1)]
-        print(str(formal) + ' ~ ' + str(data_splited_num * (i + 1)))
+    filtered_mall = analyzer.get_shop_included_with_mall_data(shop_graph_data_set=shop_with_graphs,
+                                                              show_item_data_set=shop_with_items,
+                                                              mall_info_data_set=mall_infos)
 
-        formal = data_splited_num * (i + 1)
-
-        scraper = ShopDetailScraper(data_set=new_data_set)
-        scraper.multi_get_data(num_of_process=2)
-
-    if len(new_data_set) > formal:
-        splited_data_set = new_data_set[formal:len(new_data_set)]
-        print(str(formal) + ' ~ ' + str(len(new_data_set)))
-
-        scraper = ShopDetailScraper(data_set=new_data_set)
-        scraper.multi_get_data(num_of_process=2)
+    scraper = ShopDetailScraper(data_set=filtered_mall)
+    scraper.multi_get_data(num_of_process=2)
\ No newline at end of file
