@@ -1,5 +1,5 @@
 from adnar_scraper.utility.data_loader import DataLoader
-import settings
+from adnar_scraper import settings
 
 
 class ErrorFileController:
